summaryrefslogtreecommitdiffstats
path: root/win8/metro_driver/ime/text_service.h
diff options
context:
space:
mode:
Diffstat (limited to 'win8/metro_driver/ime/text_service.h')
-rw-r--r--win8/metro_driver/ime/text_service.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/win8/metro_driver/ime/text_service.h b/win8/metro_driver/ime/text_service.h
index 6ddd21f..c3dcacd 100644
--- a/win8/metro_driver/ime/text_service.h
+++ b/win8/metro_driver/ime/text_service.h
@@ -5,11 +5,11 @@
#ifndef WIN8_METRO_DRIVER_IME_TEXT_SERVICE_H_
#define WIN8_METRO_DRIVER_IME_TEXT_SERVICE_H_
-#include <Windows.h>
+#include <windows.h>
+#include <stdint.h>
#include <vector>
-#include "base/basictypes.h"
#include "base/memory/scoped_ptr.h"
namespace metro_viewer {
@@ -31,12 +31,12 @@ class TextService {
// Updates document type with |input_scopes| and caret/composition position
// with |character_bounds|. An empty |input_scopes| indicates that IMEs
// should be disabled until non-empty |input_scopes| is specified.
// Note: |input_scopes| is defined as std::vector<int32> here rather than
// std::vector<InputScope> because the wire format of IPC message
- // MetroViewerHostMsg_ImeTextInputClientUpdated uses std::vector<int32> to
+ // MetroViewerHostMsg_ImeTextInputClientUpdated uses std::vector<int32_t> to
// avoid dependency on <InputScope.h> header.
virtual void OnDocumentChanged(
- const std::vector<int32>& input_scopes,
+ const std::vector<int32_t>& input_scopes,
const std::vector<metro_viewer::CharacterBounds>& character_bounds) = 0;
// Must be called whenever the attached window gains keyboard focus.
@@ -31,12 +31,12 @@ class TextService {
// with |character_bounds|. An empty |input_scopes| indicates that IMEs
// should be disabled until non-empty |input_scopes| is specified.
- // Note: |input_scopes| is defined as std::vector<int32> here rather than
+ // Note: |input_scopes| is defined as std::vector<int32_t> here rather than
// std::vector<InputScope> because the wire format of IPC message